@@ -2,7 +2,7 @@ from typing import Any, Callable, Dict, List, Optional, Tuple
 
 import numpy as np
 import pandas as pd
-from pandas.core.window.indexers import BaseIndexer
+from pandas.api.indexers import BaseIndexer
 from qpd import PandasLikeUtils, QPDEngine, run_sql
 from qpd.dataframe import Column, DataFrame
 from qpd.specs import (
@@ -517,9 +517,14 @@ class QPDPandasEngine(QPDEngine):
 
 
 class _RowsIndexer(BaseIndexer):
-    def __init__(self, start: Optional[int], end: Optional[int]):
+    def __init__(self, start: Optional[int], end: Optional[int], **kwargs: Any):
         window = 0 if start is None or end is None else end - start + 1
-        super().__init__(self, window_size=window, start=start, end=end)
+        kw = dict(kwargs)
+        kw["window_size"] = window
+        kw["start"] = start
+        kw["end"] = end
+
+        super().__init__(**kw)
 
     def get_window_bounds(
         self,
